@@ -53,7 +53,7 @@ hid_get_data(const void *p, const hid_item_t *h)
 	for (i = 0; i <= end; i++)
 		data |= buf[offs + i] << (i*8);
 	data >>= hpos % 8;
-	data &= (1 << hsize) - 1;
+	data &= (1ULL << hsize) - 1;
 	if (h->logical_minimum < 0) {
 		/* Need to sign extend */
 		hsize = sizeof data * 8 - hsize;
